pub const fn total_len(rows: usize, cols: usize) -> usizeExpand description
Compute the total serialized byte length for a rows × cols matrix.
pub const fn total_len(rows: usize, cols: usize) -> usizeCompute the total serialized byte length for a rows × cols matrix.